@@ -19,16 +19,23 @@ missingTable <- function(obj,...)
   temp <- lapply(temp, function(var){
     out <- as.integer(is.na(var))
     out <- factor(out,0:1,c('Avail','Non Avail'))
-    Hmisc::label(out) <- Hmisc::label(var)
+    attr(out,"label") <- attr(var,"label")
     out
   })
   temp <- as.data.frame(temp)
   Xext[varnames.orig] <- temp
 
+  X<-attr(cg,"call")$call$formula
+  X.eval <- eval(X)
+  if (inherits(X.eval, "formula"))
+    cg.update <- update(cg, data = Xext, simplify = FALSE)
+  else
+    cg.update <- update(cg, formula = Xext, simplify = FALSE)
+  
   if (inherits(obj, "createTable"))
-    ans <- update(obj, x = update(cg, data = Xext, simplify = FALSE), hide.no = 'Avail',...)
+    ans <- update(obj, x = cg.update, hide.no = 'Avail',...)
   else 
-    ans <- createTable(x = update(cg, data = Xext, simplify = FALSE), hide.no = 'Avail',...)
+    ans <- createTable(x = cg.update, hide.no = 'Avail',...)
 
   class(ans)<-c("missingTable",class(ans))
   ans
